@@ -1,12 +1,57 @@
 package Locale::Maketext::Extract::Plugin::Mason;
+{
+  $Locale::Maketext::Extract::Plugin::Mason::VERSION = '0.93';
+}
 
 use strict;
 use base qw(Locale::Maketext::Extract::Plugin::Base);
 
+# ABSTRACT: HTML::Mason (aka Mason 1) and Mason (aka Mason 2) format parser
+
+
+sub file_types {
+    return qw( * );
+}
+
+sub extract {
+    my $self = shift;
+    local $_ = shift;
+
+    my $line = 1;
+
+    # HTML::Mason (aka Mason 1)
+    while (m!\G(.*?<&\|[ ]*/l(?:oc)?(?:[ ]*,[ ]*(.*?))?[ ]*&>(.*?)</&>)!sg) {
+        my ( $vars, $str ) = ( $2, $3 );
+        $line += ( () = ( $1 =~ /\n/g ) );    # cryptocontext!
+        $self->add_entry( $str, $line, $vars );
+    }
+
+    # Mason (aka Mason 2)
+    while (
+        m!\G(.*?<%[ ]*(?:\$(?:\.|self->))fl(?:oc)?(?:[ ]*\((.*?)\))?[ ]*{[ ]*%>(.*?)</%>)!sg
+        )
+    {
+        my ( $vars, $str ) = ( $2, $3 );
+        $line += ( () = ( $1 =~ /\n/g ) );    # cryptocontext!
+        $self->add_entry( $str, $line, $vars );
+    }
+
+}
+
+
+1;
+
+__END__
+
+=pod
+
 =head1 NAME
 
-Locale::Maketext::Extract::Plugin::Mason - HTML::Mason (aka Mason 1) and Mason
-(aka Mason 2) format parser
+Locale::Maketext::Extract::Plugin::Mason - HTML::Mason (aka Mason 1) and Mason (aka Mason 2) format parser
+
+=head1 VERSION
+
+version 0.93
 
 =head1 SYNOPSIS
 
@@ -42,37 +87,6 @@ Strings inside <% $.floc { %>...</%> or <% $.fl { %>...</%> or
 
 =back
 
-=cut
-
-sub file_types {
-    return qw( * );
-}
-
-sub extract {
-    my $self = shift;
-    local $_ = shift;
-
-    my $line = 1;
-
-    # HTML::Mason (aka Mason 1)
-    while (m!\G(.*?<&\|[ ]*/l(?:oc)?(?:[ ]*,[ ]*(.*?))?[ ]*&>(.*?)</&>)!sg) {
-        my ( $vars, $str ) = ( $2, $3 );
-        $line += ( () = ( $1 =~ /\n/g ) );    # cryptocontext!
-        $self->add_entry( $str, $line, $vars );
-    }
-
-    # Mason (aka Mason 2)
-    while (
-        m!\G(.*?<%[ ]*(?:\$(?:\.|self->))fl(?:oc)?(?:[ ]*\((.*?)\))?[ ]*{[ ]*%>(.*?)</%>)!sg
-        )
-    {
-        my ( $vars, $str ) = ( $2, $3 );
-        $line += ( () = ( $1 =~ /\n/g ) );    # cryptocontext!
-        $self->add_entry( $str, $line, $vars );
-    }
-
-}
-
 =head1 SEE ALSO
 
 =over 4
@@ -106,7 +120,7 @@ Audrey Tang E<lt>cpan@audreyt.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2002-2008 by Audrey Tang E<lt>cpan@audreyt.orgE<gt>.
+Copyright 2002-2013 by Audrey Tang E<lt>cpan@audreyt.orgE<gt>.
 
 This software is released under the MIT license cited below.
 
@@ -130,6 +144,26 @@ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 DEALINGS IN THE SOFTWARE.
 
-=cut
+=head1 AUTHORS
 
-1;
+=over 4
+
+=item *
+
+Clinton Gormley <drtech@cpan.org>
+
+=item *
+
+Audrey Tang <cpan@audreyt.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2013 by Audrey Tang.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
